==> vaadin-node-maps-19.0.0-20160808.195756-146-sources.jar: org/opennms/features/vaadin/nodemaps/internal/gwt/client/event/FilteredMarkersUpdatedEvent.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2013-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.features.vaadin.nodemaps.internal.gwt.client.event;


public class FilteredMarkersUpdatedEvent extends OpenNMSEvent<FilteredMarkersUpdatedEventHandler> {
    public static Type<FilteredMarkersUpdatedEventHandler> TYPE = new Type<FilteredMarkersUpdatedEventHandler>();

    @Override
    public com.google.gwt.event.shared.GwtEvent.Type<FilteredMarkersUpdatedEventHandler> getAssociatedType() {
        return TYPE;
    }

    @Override
    public void dispatch(final FilteredMarkersUpdatedEventHandler handler) {
        handler.onFilteredMarkersUpdatedEvent(this);
    }

    @Override
    public String toDebugString() {
        return "event: FilteredMarkersUpdatedEvent:";
    }
}

==> vaadin-node-maps-22.0.1-sources.jar: org/opennms/features/vaadin/nodemaps/internal/gwt/client/event/FilteredMarkersUpdatedEvent.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2013-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.features.vaadin.nodemaps.internal.gwt.client.event;


public class FilteredMarkersUpdatedEvent extends OpenNMSEvent<FilteredMarkersUpdatedEventHandler> {
    public static Type<FilteredMarkersUpdatedEventHandler> TYPE = new Type<>();

    @Override
    public com.google.gwt.event.shared.GwtEvent.Type<FilteredMarkersUpdatedEventHandler> getAssociatedType() {
        return TYPE;
    }

    @Override
    public void dispatch(final FilteredMarkersUpdatedEventHandler handler) {
        handler.onFilteredMarkersUpdatedEvent(this);
    }

    @Override
    public String toDebugString() {
        return "event: FilteredMarkersUpdatedEvent:";
    }
}
